@@ -325,6 +325,17 @@ chmod +x /root/whp/scripts/*.sh 2>/dev/null || true
 chmod +x /root/whp/setup.sh 2>/dev/null || true
 chmod +x /root/whp/update.sh 2>/dev/null || true
 
+# Ensure backup worker cron job exists (for existing installations)
+echo "Checking backup system cron jobs..."
+if ! crontab -l 2>/dev/null | grep -q "backup-worker.php"; then
+    echo "Adding missing backup worker cron job..."
+    (crontab -l 2>/dev/null; echo "# WHP Backup System - Process pending backup creations every minute") | crontab -
+    (crontab -l 2>/dev/null; echo "* * * * * /usr/bin/php /docker/whp/web/scripts/backup-worker.php >/dev/null 2>&1") | crontab -
+    echo "✓ Backup worker cron job added"
+else
+    echo "✓ Backup worker cron job already exists"
+fi
+
 # Run any post-update scripts
 if [ -f /root/whp/scripts/post-update.sh ]; then
     echo ""
