@@ -619,68 +619,108 @@ class haproxy_manager {
      * @return bool True on success, false on failure
      */
     public function block_ip($ip_address, $reason = 'Manual block', $blocked_by = 'WHP System') {
-        if (!filter_var($ip_address, FILTER_VALIDATE_IP)) {
-            error_log("HAProxy Manager: Invalid IP address provided for blocking: $ip_address");
+        if (!$this->validate_ip_or_cidr($ip_address)) {
+            error_log("HAProxy Manager: Invalid IP address or CIDR provided for blocking: $ip_address");
             return false;
         }
-        
-        // Check if IP is already blocked to avoid unnecessary API calls
-        if ($this->is_ip_blocked($ip_address)) {
-            // IP is already blocked, no need to send duplicate block command
-            return true;
+
+        // For CIDR ranges, skip the is_blocked check as it's more complex
+        // Let HAProxy API handle whether it's already blocked
+        if (strpos($ip_address, '/') === false) {
+            // Check if IP is already blocked to avoid unnecessary API calls (single IP only)
+            if ($this->is_ip_blocked($ip_address)) {
+                // IP is already blocked, no need to send duplicate block command
+                return true;
+            }
         }
-        
+
         $data = [
             'ip_address' => $ip_address,
             'reason' => $reason,
             'blocked_by' => $blocked_by
         ];
-        
+
         $result = $this->makeApiRequest('POST', '/api/blocked-ips', $data);
-        
+
         if ($result['success']) {
-            error_log("HAProxy Manager: Successfully blocked IP $ip_address");
+            error_log("HAProxy Manager: Successfully blocked IP/CIDR $ip_address");
             return true;
-        } elseif (isset($result['data']['status']) && $result['data']['status'] === 'error' && 
+        } elseif (isset($result['data']['status']) && $result['data']['status'] === 'error' &&
                   strpos($result['data']['message'], 'already blocked') !== false) {
             // IP is already blocked, consider this a success but don't log as it's expected
             return true;
         }
-        
-        error_log("HAProxy Manager: Failed to block IP $ip_address - " . ($result['error'] ?? 'Unknown error'));
+
+        error_log("HAProxy Manager: Failed to block IP/CIDR $ip_address - " . ($result['error'] ?? 'Unknown error'));
         return false;
     }
     
     /**
-     * Unblock an IP address in HAProxy
-     * 
-     * @param string $ip_address IP address to unblock
+     * Validates if a string is a valid IP address or CIDR notation
+     *
+     * @param string $input IP address or CIDR notation (e.g., "192.168.1.0/24")
+     * @return bool True if valid IP or CIDR, false otherwise
+     */
+    private function validate_ip_or_cidr($input) {
+        // Check if it's a plain IP address
+        if (filter_var($input, FILTER_VALIDATE_IP)) {
+            return true;
+        }
+
+        // Check if it's CIDR notation
+        if (strpos($input, '/') !== false) {
+            list($ip, $mask) = explode('/', $input, 2);
+
+            // Validate IP part
+            if (!filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4)) {
+                return false;
+            }
+
+            // Validate mask (0-32 for IPv4)
+            if (!is_numeric($mask) || $mask < 0 || $mask > 32) {
+                return false;
+            }
+
+            return true;
+        }
+
+        return false;
+    }
+
+    /**
+     * Unblock an IP address or CIDR range in HAProxy
+     *
+     * @param string $ip_address IP address or CIDR notation to unblock
      * @return bool True on success, false on failure
      */
     public function unblock_ip($ip_address) {
-        if (!filter_var($ip_address, FILTER_VALIDATE_IP)) {
-            error_log("HAProxy Manager: Invalid IP address provided for unblocking: $ip_address");
+        if (!$this->validate_ip_or_cidr($ip_address)) {
+            error_log("HAProxy Manager: Invalid IP address or CIDR provided for unblocking: $ip_address");
             return false;
         }
-        
-        // Check if IP is actually blocked before trying to unblock
-        if (!$this->is_ip_blocked($ip_address)) {
-            // IP is not blocked, no need to send unblock command
-            return true;
+
+        // For CIDR ranges, skip the is_blocked check as it's more complex
+        // Let HAProxy API handle whether it's actually blocked
+        if (strpos($ip_address, '/') === false) {
+            // Check if IP is actually blocked before trying to unblock (single IP only)
+            if (!$this->is_ip_blocked($ip_address)) {
+                // IP is not blocked, no need to send unblock command
+                return true;
+            }
         }
-        
+
         $data = [
             'ip_address' => $ip_address
         ];
-        
+
         $result = $this->makeApiRequest('DELETE', '/api/blocked-ips', $data);
-        
+
         if ($result['success']) {
-            error_log("HAProxy Manager: Successfully unblocked IP $ip_address");
+            error_log("HAProxy Manager: Successfully unblocked IP/CIDR $ip_address");
             return true;
         }
-        
-        error_log("HAProxy Manager: Failed to unblock IP $ip_address - " . ($result['error'] ?? 'Unknown error'));
+
+        error_log("HAProxy Manager: Failed to unblock IP/CIDR $ip_address - " . ($result['error'] ?? 'Unknown error'));
         return false;
     }
     
